package view;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.GridLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.BorderFactory;
import javax.swing.Box;
import javax.swing.BoxLayout;
import javax.swing.JButton;
import javax.swing.JFileChooser;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JList;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTextField;

import controler.AlarmListListener;
import controler.Controler;
import model.*;

@SuppressWarnings("serial")
public class AlarmFrame extends JFrame {
    private static final String Title_End = " - Alerte";
    private AlarmList alarms;
    private JList<Alarm> lstAlarms;
    private JTextField txtName;
    private JTextField txtTime;
    private JButton deleteButton;
    private JButton modifyButton;
    private MenuBar menus;
    private StatusBar info;

    public AlarmFrame(AlarmList l, Controler controler) {
    	alarms = l;
        updateTitle();
        menus = new MenuBar(controler);
        setJMenuBar(menus);

        lstAlarms = new JList<Alarm>();
        lstAlarms.addListSelectionListener(new AlarmListListener(lstAlarms, this));
        JScrollPane listScrollPane = new JScrollPane(lstAlarms);
        listScrollPane.setPreferredSize(new Dimension(250, 80));
        add(listScrollPane, BorderLayout.CENTER);

        JPanel editAlarmPanel = new JPanel();
        editAlarmPanel.setLayout(new BoxLayout(editAlarmPanel, BoxLayout.Y_AXIS));

        Dimension dimForLabel = new Dimension(60, 20);
        Dimension dimForField = new Dimension(300, 20);

        JPanel namePanel = new JPanel();
        namePanel.setLayout(new BoxLayout(namePanel, BoxLayout.X_AXIS));
        namePanel.setBorder(BorderFactory.createEmptyBorder(10, 10, 0, 10));
        JLabel nameLabel = new JLabel("Nom :");
        nameLabel.setMaximumSize(dimForLabel);
        namePanel.add(nameLabel);
        namePanel.add(Box.createRigidArea(new Dimension(10, 0)));
        txtName = new JTextField();
        txtName.setMaximumSize(dimForField);
        namePanel.add(txtName);
        editAlarmPanel.add(namePanel);

        JPanel timePanel = new JPanel();
        timePanel.setLayout(new BoxLayout(timePanel, BoxLayout.X_AXIS));
        timePanel.setBorder(BorderFactory.createEmptyBorder(10, 10, 0, 10));
        JLabel timeLabel = new JLabel("Heure :");
        timeLabel.setMaximumSize(dimForLabel);
        timePanel.add(timeLabel);
        timePanel.add(Box.createRigidArea(new Dimension(10, 0)));
        txtTime = new JTextField();
        txtTime.setMaximumSize(dimForField);
        timePanel.add(txtTime);
        editAlarmPanel.add(timePanel);

        JPanel cmdPanel = new JPanel();
        cmdPanel.setLayout(new BoxLayout(cmdPanel, BoxLayout.LINE_AXIS));
        cmdPanel.setBorder(BorderFactory.createEmptyBorder(10, 10, 10, 10));
        cmdPanel.add(Box.createHorizontalGlue());
        modifyButton = new JButton("Modifier");
        modifyButton.addActionListener((ActionEvent e) -> {
            Alarm alarm = lstAlarms.getSelectedValue();
            if (alarm != null) {
                controler.changeAlarm(alarm, txtName.getText(), txtTime.getText());
            }
        });
        cmdPanel.add(modifyButton);
        cmdPanel.add(Box.createRigidArea(new Dimension(10, 0)));
        deleteButton = new JButton("Suppr.");
        deleteButton.addActionListener((ActionEvent e) -> {
            Alarm alarm = lstAlarms.getSelectedValue();
            if (alarm != null) {
            	controler.removeAlarm(alarm);
            }
        });
        cmdPanel.add(deleteButton);
        editAlarmPanel.add(cmdPanel);
        
        add(editAlarmPanel, BorderLayout.EAST);
        
        info = new StatusBar();
        add(info, BorderLayout.SOUTH);
        pack();
        setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        setLocationRelativeTo(null);
    }
    public void allowSaveItem(boolean b) {
    	menus.allowSaveItem(b);
    }
    public void updateAlarmList() {
        lstAlarms.setListData(alarms.toArray(new Alarm[0]));
    }
    public void updateTitle() {
        setTitle(alarms.fileName() + Title_End);
    }
    public void editorForNewAlarm() {
    	txtName.setText("");
    	txtTime.setText("");
    	deleteButton.setEnabled(false);
    	modifyButton.setEnabled(false);
    }
    public void editorForSelection() {
    	Alarm a = lstAlarms.getSelectedValue();
        if (a != null) {
	    	txtName.setText(a.getName());
	    	txtTime.setText(a.getTime());
	    	deleteButton.setEnabled(true);
	    	modifyButton.setEnabled(true);
        }
    }
}
